/*
 * responsive-carousel touch drag extension
 * https://github.com/filamentgroup/responsive-carousel
 *
 * Copyright (c) 2012 Filament Group, Inc.
 * Licensed under the MIT, GPL licenses.
 */

 (function($) {
  var pluginName = "revolver",
    initSelector = "." + pluginName,
    noTrans = pluginName + "-no-transition",
    touchMethods = {
      _dragBehavior: function(){
        var origin,
          data = {},
          deltaY,
          xPerc,
          yPerc,
          emitEvents = function( e ){
            var touches = e.touches || e.originalEvent.touches,
              $elem = $( e.target ).closest( initSelector );
            
            if( e.type === "touchstart" ){
              origin = {
                x : touches[ 0 ].pageX,
                y: touches[ 0 ].pageY
              };
            }

            if( touches[ 0 ] && touches[ 0 ].pageX ){
              data.touches = touches;
              data.deltaX = touches[ 0 ].pageX - origin.x;
              data.deltaY = touches[ 0 ].pageY - origin.y;
              data.w = $elem.first().width();
              data.h = $elem.first().height();
              data.xPercent = data.deltaX / data.w;
              data.yPercent = data.deltaY / data.h;
              data.srcEvent = e;
            }

            $elem.trigger( "drag" + e.type.split( "touch" )[ 1 ], data );
            return data;
          };

        $( this )
          .bind( "touchstart", function( e ){
            $( this ).addClass( noTrans );
            emitEvents( e );
          } )
          .bind( "touchmove", function( e ){
            var data = emitEvents( e );

            if( Math.abs( data.deltaX ) > 35 && Math.abs( data.deltaY ) < 35 && data.touches.length === 1 ){
              return false;
            }
            e.stopPropagation();
          } )
          .bind( "touchend", function( e ){
            $( this ).removeClass( noTrans );
            emitEvents( e );
          } );
      }
    };
      
  // add methods
  $.extend( $.fn[ pluginName ].prototype, touchMethods );

  // DOM-ready auto-init
  $( initSelector ).live( "create." + pluginName, function(){
    $( this )[ pluginName ]( "_dragBehavior" );
  } );

 }(jQuery));
